/**
 * Run process persistently.
 * @memberof module:apeman/util/clustering
 * @function persist
 * @param {object} cluster - Node cluster.
 * @parma {object} config - Persist configuration.
 */


"use strict";

var PersistForker = require('./persist_forker');

/** @lends persist */
function persist(cluster, config) {

    var forker = new PersistForker(config.basedir);
    if (cluster.isMaster) {

        forker.on('fork', function (pid) {
            console.log('\tWorker start with pid:', pid);
        });

        forker.on('unfork', function (pid) {
            console.error('Worker dead:', pid);
        });

        forker.on('refork', function (pid) {
            console.log('Restart worker:', pid);
        });

        forker.on('start', config.start);
        forker.on('stop', config.stop);

        forker.bindMaster(cluster, process);
    } else {
        forker.on('start', config.wokerStart);
        forker.on('stop', config.workerStop);
        forker.bindWorker(cluster, process);
    }
};

persist.kill = function (basedir, callback) {
    var forker = new PersistForker(basedir);
    forker.kill(callback);
}


module.exports = persist;