/**
 * Helper for task.
 * @memberof module:apeman-util/lib/tasking
 * @constructor TaskHelper
 * @param {string} basedir - Base directory path.
 * @see {@link module:apeman-util|util}
 * @author Taka Okunishi
 */

"use strict";

var u = require('../../lib'),
    ext = u.ext,
    core = u.core,
    yesno = ext.yesno,
    async = ext.async,
    fs = core.fs,
    path = core.path;

/** @lends TaskHelper */
function TaskHelper(basedir) {
    var s = this;
    s.init(basedir || process.cwd());
};

/**
 * Initialize task helper.
 * @param {sring} basedir - Base directory path.
 */
TaskHelper.prototype.init = function (basedir) {
    var s = this;
    s.basedir = basedir;
}

/** @borrows async */
TaskHelper.prototype.async = async;
/** @borrows yesno */
TaskHelper.prototype.yesno = yesno;
/** @borrows fs */
TaskHelper.prototype.fs = fs;
/** @borrows path */
TaskHelper.prototype.path = path;


/**
 * Done function.
 * @param {string} msg - Message to display.
 * @param {boolean} [exit=false] - Exit when done.
 * @returns {function} - Done function.
 */
TaskHelper.prototype.done = function (msg, exit) {
    return function (err) {
        if (err) {
            console.error(err);
        } else {
            console.log(msg);
        }
        if (!!exit) {
            process.nextTick(function () {
                var exitCode = err ? 1 : 0;
                process.exit(exitCode);
            });
        }
    }
};

module.exports = TaskHelper;